<?php
/**
 * @version   4.0.8 October 3, 2013
 * @author Webempresa http://www.webempresa.com
 * @copyright Copyright (C) 2013 Webempresa
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */

/**
 * Check to see if Gantry is Active
 * 
 * @return bool
 */
// Change number or products per row to 4
add_filter('loop_shop_columns', 'loop_columns');
if (!function_exists('loop_columns')) {
	function loop_columns() {
		return 4; // 4 products per row
	}
}

remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
add_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_upsells', 15 );
 
if ( ! function_exists( 'woocommerce_output_upsells' ) ) {
	function woocommerce_output_upsells() {
	    woocommerce_upsell_display( 3,3 ); // Display 3 products in rows of 3
	}
}

// Para mostrar 12 productos por página en la tienda Woocommerce
add_filter( 'loop_shop_per_page', create_function( '$cols', 'return 12;' ), 20 );

add_action( 'widgets_init', 'override_woocommerce_widgets', 15 );
 
function override_woocommerce_widgets() {
  // Para sobreescribir las clases de los widgets de Woocommerce
 
  if ( class_exists( 'WC_Widget_Featured_Products' ) ) {
    unregister_widget( 'WC_Widget_Featured_Products' );
 
    include_once( 'woocommerce/widget-featured-products.php' );
 
    register_widget( 'Custom_WC_Widget_Featured_Products' );
  }

  if ( class_exists( 'WC_Widget_Best_Sellers' ) ) {
    unregister_widget( 'WC_Widget_Best_Sellers' );
 
    include_once( 'woocommerce/widget-best-sellers.php' );
 
    register_widget( 'Custom_WC_Widget_Best_Sellers' );
  }
 
}

// Use WC 2.0 variable price format, now include sale price strikeout
add_filter( 'woocommerce_variable_sale_price_html', 'wc_wc20_variation_price_format', 10, 2 );
add_filter( 'woocommerce_variable_price_html', 'wc_wc20_variation_price_format', 10, 2 );
function wc_wc20_variation_price_format( $price, $product ) {
	// Main Price
	$prices = array( $product->get_variation_price( 'min', true ), $product->get_variation_price( 'max', true ) );
	$price = $prices[0] !== $prices[1] ? sprintf( __( '%1$s', 'woocommerce' ), wc_price( $prices[0] ) ) : wc_price( $prices[0] );
	// Sale Price
	$prices = array( $product->get_variation_regular_price( 'min', true ), $product->get_variation_regular_price( 'max', true ) );
	sort( $prices );
	$saleprice = $prices[0] !== $prices[1] ? sprintf( __( '%1$s', 'woocommerce' ), wc_price( $prices[0] ) ) : wc_price( $prices[0] );
 
	if ( $price !== $saleprice ) {
		$price = '<span class="from">' . _x( 'From:', 'min_price', 'woocommerce' ) . ' </span> <del>' . $saleprice . '</del> <ins>' . $price . '</ins>';
	}
	return $price;
}

function limitStringByWord ($string, $maxlength, $suffix = '') {
	if(strlen( $string )<=$maxlength) return $string;
	$string = substr( $string, 0, $maxlength );
	$index = strrpos( $string, ' ' );
	if($index === FALSE) {
		return $string;
	} else {
		return substr( $string, 0, $index ).$suffix;
	}
}

function gantry_theme_is_gantry_active()
{
	$active = false;
	$active_plugins = get_option( 'active_plugins' );
	if ( in_array( 'gantry/gantry.php', $active_plugins ) ) {
		$active = true;
	}
	if ( !function_exists( 'is_plugin_active_for_network' ) )
		require_once( ABSPATH . '/wp-admin/includes/plugin.php' );
	if ( is_plugin_active_for_network( 'gantry/gantry.php' ) ) {
		$active = true;
	}
	return $active;
}

/**
 * @return void
 */
function gantry_admin_missing_nag()
{
	$msg = __( 'The active theme requires the Gantry Framework Plugin to be installed and active' );
	echo "<div class='update-nag'>$msg</div>";
}

/**
 * @return void
 */
function gantry_missing_nag()
{
	echo 'This theme requires the Gantry Framework Plugin to be installed and active.';
	die(0);
}


if ( !gantry_theme_is_gantry_active() ) {
	if ( !is_admin() ) {
		add_filter( 'template_include', 'gantry_missing_nag', -10, 0 );
	}
	else {
		add_action( 'admin_notices', 'gantry_admin_missing_nag' );
	}
}

// This will always set the Posts Per Page option to 1 to fix the WordPress bug
// when the pagination would return 404 page. To set the number of posts shown
// on the blog page please use the field under Theme Settings > Content > Blog > Post Count
function gantry_posts_per_page() {
	if( get_option( 'posts_per_page' ) != '1' ) update_option( 'posts_per_page', '1' );
}

add_action( 'init', 'gantry_posts_per_page' );

/**
 * Function to generate post pagination
 */
function gantry_pagination($custom_query) {
	global $gantry;

	if ( !$current_page = get_query_var( 'paged' ) ) $current_page = 1;
			
	$permalinks = get_option( 'permalink_structure' );
	if( is_front_page() ) {
		$format = empty( $permalinks ) ? '?paged=%#%' : 'page/%#%/';
	} else {
		$format = empty( $permalinks ) || is_search() ? '&paged=%#%' : 'page/%#%/';
	}

	$big = 999999999; // need an unlikely integer

	$pagination = paginate_links( array(
		'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' => $format,
		'current' => $current_page,
		'total' => $custom_query->max_num_pages,
		'mid_size' => $gantry->get( 'pagination-count', '8' ),
		'type' => 'list',
		'next_text' => _r( 'Next' ),
		'prev_text' => _r( 'Previous' )
	) );

	$pagination = explode( "\n", $pagination );
	$pagination_mod = array();

	foreach ( $pagination as $item ) {
		( preg_match( '/<ul class=\'page-numbers\'>/i', $item ) ) ? $item = str_replace( '<ul class=\'page-numbers\'>', '<ul>', $item ) : $item;
		( preg_match( '/class="prev/i', $item ) ) ? $item = str_replace( '<li', '<li class="pagination-prev"', $item ) : $item;
		( preg_match( '/class="next/i', $item ) ) ? $item = str_replace( '<li', '<li class="pagination-next"', $item ) : $item;
		( preg_match( '/page-numbers/i', $item ) ) ? $item = str_replace( 'page-numbers', 'page-numbers pagenav', $item ) : $item;
		$pagination_mod[] .= $item;
	}
	
	?>
	
	<div class="pagination">

		<?php if( $gantry->get( 'pagination-show-results', '1' ) ) : ?>
		<p class="counter">
			<?php printf( _r( 'Page %1$s of %2$s' ), $current_page, $custom_query->max_num_pages ); ?>
		</p>
		<?php endif; ?>
	
		<?php foreach( $pagination_mod as $page ) {
			echo $page;
		} ?>

	</div>


<?php }